@@ -10,7 +10,9 @@ s2n <- function(seq, levels = s2c("acgt"), base4 = TRUE, forceToLower = TRUE)
   #
   # Check that sequence is a vector of chars:
   #
-  if(nchar(seq[1]) > 1) stop("sequence is not a vector of chars")
+  if(!is.na(seq[1])){
+    if(nchar(seq[1]) > 1) stop("sequence is not a vector of chars")
+  }
   #
   # Force to lower-case letters if requested:
   #
@@ -20,4 +22,4 @@ s2n <- function(seq, levels = s2c("acgt"), base4 = TRUE, forceToLower = TRUE)
     unclass(factor(seq, levels = levels ) ) - 1
   else
     unclass(factor(seq, levels = levels ) )
-}
\ No newline at end of file
+}
